@@ -32,9 +32,9 @@ int main(int, char *argv[])
 		     "database=" + C.dbname() + ", "
 		     "username=" + C.username() + ", "
 		     "hostname=" + HostName + ", "
-		     "port=" + ToString(C.port()) + ", "
+		     "port=" + to_string(C.port()) + ", "
 		     "options='" + C.options() + "', "
-		     "backendpid=" + ToString(C.backendpid()) + "\n");
+		     "backendpid=" + to_string(C.backendpid()) + "\n");
 
     work T(C, "test21");
 
@@ -44,14 +44,22 @@ int main(int, char *argv[])
 		     "database=" + C.dbname() + ", "
 		     "username=" + C.username() + ", "
 		     "hostname=" + HostName + ", "
-		     "port=" + ToString(C.port()) + ", "
+		     "port=" + to_string(C.port()) + ", "
 		     "options='" + C.options() + "', "
-		     "backendpid=" + ToString(C.backendpid()) + "\n");
+		     "backendpid=" + to_string(C.backendpid()) + "\n");
 
+    string P;
+    from_string(C.port(), P);
+    if (P != to_string(C.port()))
+      throw runtime_error("from_string(const char[],std::string &) "
+		"inconsistent with to_string(const char[])");
+    if (to_string(P) != P)
+      throw runtime_error("to_string(std::string) turns '" + P + "' "
+	  "into '" + to_string(P) + "'");
 
     result R( T.exec("SELECT * FROM pg_tables") );
 
-    T.process_notice(ToString(R.size()) + " "
+    T.process_notice(to_string(R.size()) + " "
 		     "result tuples in transaction " +
 		     T.name() +
 		     "\n");
@@ -62,7 +70,7 @@ int main(int, char *argv[])
       string N;
       c[0].to(N);
 
-      cout << '\t' << ToString(c.num()) << '\t' << N << endl;
+      cout << '\t' << to_string(c.num()) << '\t' << N << endl;
     }
 
     T.commit();
